import { css } from "@linaria/core";
import { Button, Form, Input } from "ant-design-vue";
import { defineComponent, reactive } from "vue";
import { useAuth } from "../..";
import LoginTabs from "./LoginTabs";

const loginTabs = {
  default: [{ label: "用户登录", value: "default" }],
  company: [
    {
      label: "个人登录",
      value: "default",
    },
    {
      label: "企业登录",
      value: "company",
    },
  ],
};

const layout = {
  wrapperCol: { span: 24 },
};
const tailLayout = {
  wrapperCol: { span: 24 },
};

export default defineComponent({
  setup() {
    const auth = useAuth();

    const state = reactive({
      loading: false,
      loginType: "default",
    });

    const formState = reactive({
      phone: "",
      password: "",
    });

    const validatePass = async (rule: any, value: string) => {
      if (!value) {
        return Promise.reject("请输入正确的账号");
      } else {
        return Promise.resolve();
      }
    };

    const rules = reactive({
      phone: [
        {
          required: true,
          validator: validatePass,
          trigger: "change",
        },
      ],
      password: [
        { required: true, message: "密码不能为空", trigger: "change" },
        {
          min: 1,
          max: 18,
          message: "密码长度为6~18位字符",
          trigger: "change",
        },
      ],
    });

    const { validate, validateInfos } = Form.useForm(formState, rules);

    async function submit() {
      try {
        state.loading = true;
        const values = await validate();
        await auth.actions.pwdLogin(values);
      } finally {
        state.loading = false;
      }
    }

    return () => (
      <div class={styleRoot}>
        <LoginTabs
          options={
            auth.config.needCompanyLogin ? loginTabs.company : loginTabs.default
          }
          onChange={({ value }) => (state.loginType = value)}
        />
        <Form {...layout} name="basic">
          <Form.Item name="phone" {...validateInfos.phone}>
            <Input
              placeholder="请输入手机号码"
              allowClear
              v-model={[formState.phone, "value"]}
              maxlength={30}
            />
          </Form.Item>
          <Form.Item name="password" {...validateInfos.password}>
            <Input.Password
              placeholder="请输入密码"
              allowClear
              v-model={[formState.password, "value"]}
              maxlength={12}
            />
          </Form.Item>
          <Form.Item {...tailLayout}>
            <Button
              htmlType="submit"
              block
              type="primary"
              size="large"
              shape="round"
              loading={state.loading}
              onClick={submit}
            >
              立即登录
            </Button>
          </Form.Item>
        </Form>
        <div class="login-more">
          {auth.config.needRegister ? (
            <router-link to="/register">注册账号</router-link>
          ) : (
            <div></div>
          )}
          {auth.config.needResetPwd ? (
            <router-link to="/forget">忘记密码</router-link>
          ) : (
            <div></div>
          )}
        </div>
      </div>
    );
  },
});

const styleRoot = css`
  width: 490px;
  padding: 44px;
  background-color: @inf-component-bg;

  .login-more {
    display: flex;
    justify-content: space-between;
  }

  .ant-input-affix-wrapper {
    background-color: @inf-input-bg;
    input {
      background-color: @inf-input-bg;
    }
  }
`;
