import { css } from "@linaria/core";
import { defineComponent, reactive } from "vue";
import { array } from "vue-types";

export default defineComponent({
  props: {
    options: array<{ label: string; value: any }>(),
  },
  emits: ["change"],
  setup(props, { emit }) {
    const state = reactive({
      tabIndex: 0,
    });

    function onChange(item: any, i: number) {
      state.tabIndex = i;
      emit("change", item);
    }

    return () => (
      <div class={styleRoot}>
        {props.options?.map((item, i) => {
          return (
            <div
              class={["tabItem", state.tabIndex === i && "active"]}
              key={i}
              onClick={() => onChange(item, i)}
            >
              {item.label}
            </div>
          );
        })}
      </div>
    );
  },
});

const styleRoot = css`
  display: flex;
  justify-content: center;
  margin-bottom: 40px;
  .tabItem {
    padding: 0 20px;
    font-size: 22px;
    font-weight: bold;
    color: @inf-text-passive-color;
    cursor: pointer;

    &.active {
      color: @inf-text-active-color;
    }

    & + .tabItem {
      border-left: 1px solid @inf-border-color;
    }
  }
`;
