import { css } from "@linaria/core";
import { Button, Form, Input } from "ant-design-vue";
import { queenApi } from "queenjs";
import { defineComponent, reactive } from "vue";
import { useAuth } from "../..";
import { CaptchaInput } from "./captcha";
import LoginTabs from "./LoginTabs";

const layout = {
  wrapperCol: { span: 24 },
};
const tailLayout = {
  wrapperCol: { span: 24 },
};

export default defineComponent({
  setup() {
    const auth = useAuth();

    const state = reactive({
      loading: false,
    });

    const formState = reactive({
      phone: "",
      code: "",
      password: "",
      rePwd: "",
    });

    const rules = reactive({
      phone: [{ required: true, message: "手机号不能为空", trigger: "change" }],
      code: [{ required: true, message: "验证码不能为空", trigger: "change" }],
      password: [
        { required: true, message: "密码不能为空", trigger: "change" },
      ],
      rePwd: [{ required: true, message: "请确认密码", trigger: "change" }],
    });

    const { validate, validateInfos } = Form.useForm(formState, rules);

    async function submit() {
      try {
        state.loading = true;
        const { rePwd, ...formData } = await validate();
        if (rePwd !== formData.password) {
          queenApi.messageError("输入密码不一致！");
          return;
        }
        await auth.actions.personRegister(formData);
      } finally {
        state.loading = false;
      }
    }

    function getCodeByClick() {
      return auth.actions.getSmsCode({
        phone: formState.phone,
        use: "register",
      });
    }

    return () => (
      <div class={styleRoot}>
        <LoginTabs options={[{ label: "用户注册", value: "" }]} />
        <Form {...layout} name="basic">
          <Form.Item name="phone" {...validateInfos.phone}>
            <Input
              placeholder="请输入手机号码"
              v-model={[formState.phone, "value"]}
              maxlength={30}
            />
          </Form.Item>
          <Form.Item name="code" {...validateInfos.code}>
            <CaptchaInput
              disabled={!/^1[3456789]\d{9}$/.test(formState.phone)}
              value={formState.code}
              onChange={(v) => (formState.code = v)}
              onGetCode={getCodeByClick}
            />
          </Form.Item>
          <Form.Item name="password" {...validateInfos.password}>
            <Input
              onFocus={(e: any) => (e.target.type = "password")}
              placeholder="请设置密码"
              v-model={[formState.password, "value"]}
              maxlength={12}
            />
          </Form.Item>
          <Form.Item name="rePwd" {...validateInfos.rePwd}>
            <Input
              onFocus={(e: any) => (e.target.type = "password")}
              placeholder="再次确认密码"
              v-model={[formState.rePwd, "value"]}
              maxlength={12}
            />
          </Form.Item>
          <Form.Item {...tailLayout}>
            <Button
              htmlType="submit"
              block
              type="primary"
              size="large"
              shape="round"
              loading={state.loading}
              onClick={submit}
            >
              立即注册
            </Button>
          </Form.Item>
        </Form>
        <router-link to="/" class="backLoginLink">
          {/* <IconBack /> */}
          返回登录
        </router-link>
      </div>
    );
  },
});

const styleRoot = css`
  width: 490px;
  padding: 44px;
  background-color: @inf-component-bg;

  .backLoginLink {
    display: flex;
    margin: 0 auto;
    width: 120px;
    align-items: center;
    color: @inf-primary-color;
    svg {
      font-size: 30px;
    }
  }
`;
