import { defineComponent, onUnmounted, ref } from "vue";
import { Input, Button } from "ant-design-vue";
import { bool, func, string } from "vue-types";
import { css } from "@linaria/core";

export const CaptchaInput = defineComponent({
  props: {
    value: string(),
    disabled: bool(),
    bordered: bool().def(true),
    onGetCode: func(),
    placeholder: string().def("请输入验证码"),
    text: string().def("发送验证码"),
    CoundownText: string().def("秒后重发"),
  },
  emits: ["change"],
  setup(props, { emit }) {
    const time = ref(0);
    let timer: any = null;

    onUnmounted(() => {
      clearInterval(timer);
    });

    async function getCode() {
      const err = await props.onGetCode?.();
      if (!err) {
        time.value = 60;
        timer = setInterval(() => {
          time.value--;
          if (time.value === 0) {
            clearInterval(timer);
          }
        }, 1000);
      }
    }

    return () => {
      const { CoundownText, placeholder, text } = props;

      const sending = time.value !== 0;
      const btnTxt = sending ? `${time.value}${CoundownText}` : text;
      return (
        <div class={rootStyle}>
          <Input
            bordered={props.bordered}
            type="phone"
            value={props.value}
            placeholder={placeholder}
            maxlength={6}
            onChange={(e) => emit("change", e.target.value)}
          />
          <Button
            type="text"
            disabled={props.disabled || sending}
            onClick={getCode}
          >
            {btnTxt}
          </Button>
        </div>
      );
    };
  },
});

const rootStyle = css`
  display: flex;
  align-items: center;
  input {
    flex: 1;
  }
`;
